@@ -32,10 +32,11 @@ class WorkflowPipeline:
 
 class Workflow:
 
-    def __init__(self):
+    def __init__(self, access_token:str):
         self.stores: List[WorkflowStore] = []
         self.pipelines: List[WorkflowPipeline] = []
         self.connectors: List[WorkflowConnector] = []
+        self.access_token = access_token
 
     def add_store(self, name: str, ref: str):
         self.stores.append(WorkflowStore(name, ref))
